@@ -105,6 +105,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
         '''.format(datetime.datetime.now().year, n))
+        print('INFO[000] create the LICENSE file')
         self.createFile('./'+n+'/', 'pyproject.toml', '''
 [build-system]
 requires = [
@@ -113,7 +114,9 @@ requires = [
 ]
 build-backend = "setuptools.build_meta"        
         ''')
+        print('INFO[001] create the README.md file')
         self.createFile('./'+n+'/', 'README.md', '''#your project readme''')
+        print('INFO[002] create the setup.py file')
         self.createFile('./'+n+'/', 'setup.py', '''
 import setuptools
 
@@ -137,7 +140,10 @@ setuptools.setup(
 )    
         '''.format(n, author, author_email, description, url, project_urls, classifiers, python_requires, install_requires))
         self.createDir('./'+n+'/'+'src/')
+        print('INFO[004] create the src dir')
         self.createFile('./'+n+'/'+'src/', '__init__.py', '# your python file')
+        print('INFO[005] create the __init__.py file')
+        print(f'{n} is success')
 
     def createDir(self, dirName):
         name = dirName
